@@ -1,2 +1,2 @@
-from ._chain_proxy import DataProxy
+from ._chain_proxy import ChainProxy
 from ._methods import dataclass_proxy, get_value
